@@ -62,6 +62,7 @@ class Garden(object):
             WHERE key = NEW.key
     '''
 
+    select_all_fmt = 'SELECT key, value FROM {name}'
     select_fmt = 'SELECT value FROM {name} WHERE key = %s'
     insert_fmt = 'INSERT INTO {name} (key, value) VALUES (%s, %s)'
 
@@ -71,7 +72,8 @@ class Garden(object):
 
         # Format the class name into the table and rule definitions.
         self.table_def = self.def_fmt.format(name=self.name)
-        self.replace_cmd = self.replace_fmt.format(name=self.name)
+        self.replace_def = self.replace_fmt.format(name=self.name)
+        self.select_all_cmd = self.select_all_fmt.format(name=self.name)
         self.select_cmd = self.select_fmt.format(name=self.name)
         self.insert_cmd = self.insert_fmt.format(name=self.name)
 
@@ -90,11 +92,19 @@ class Garden(object):
                 SELECT 1 FROM pg_rules WHERE rulename = 'replace_{name}'
                 '''.format(name=self.name))
             if not cur.fetchone():
-                cur.execute(self.replace_cmd)
+                cur.execute(self.replace_def)
 
         conn.commit()
         self.pool.putconn(conn)
 
+    def getall(self):
+        conn = self.pool.getconn()
+        with conn.cursor() as cur:
+            cur.execute(self.select_all_cmd)
+            pairs = cur.fetchall()
+        self.pool.putconn(conn)
+        return dict(pairs)
+
     def __getitem__(self, key):
         '''Retrieve a cucumber from the Garden.'''
 
